<!--排查单位查询-筛选弹层-->
<template>
  <van-popup v-model="isShowPopup" :close-on-click-overlay="false" position="right"
    :style="{ width: '100%', height: '100%' }" @open="open" @closed="closed">

    <div class="details-container">
      <!--  头部  -->
      <van-sticky>
        <van-nav-bar title="详情" left-arrow @click-left="_ => $emit('update:isShow', false)" />
      </van-sticky>

      <van-form label-width="auto">
        <van-collapse v-model="activeNames">
          <van-collapse-item title="排查计划信息" name="1" icon="more-o">
            <van-field label="排查月度" input-align="right">
              <template #input>
                {{ formData.checkYearMonth || '-' }}
              </template>
            </van-field>
            <van-field label="排查名称" input-align="right" rows="1" autosize placeholder="-" type="textarea"
              v-model="formData.checkName" readonly />
            <van-field label="排查方式" input-align="right">
              <template #input>
                {{ dictionaryEscape(checkTypeOpt, formData.checkType) || '-' }}
              </template>
            </van-field>
            <van-field label="开始时间" input-align="right">
              <template #input>
                {{ formData.checkStartDate || '-' }}
              </template>
            </van-field>
            <van-field label="结束时间" input-align="right">
              <template #input>
                {{ formData.checkEndDate || '-' }}
              </template>
            </van-field>
            <van-field label="排查内容" input-align="right" rows="1" autosize placeholder="-" type="textarea"
              v-model="formData.checkContent" readonly />
          </van-collapse-item>
          <van-collapse-item title="排查计划明细" name="2" icon="comment-circle-o">
            <div class="multiple-box">
              <div class="multiple-box-item" v-for="(item, index) in formData.detail" :key="index">
                <van-field :label="`计划明细${index + 1}：`" input-align="right" />
                <van-field label="排查月度" input-align="right">
                  <template #input>
                    {{ item.checkYearMonth || '-' }}
                  </template>
                </van-field>
                <van-field label="排查单位" input-align="right">
                  <template #input>
                    {{ dictionaryEscape(checkCompanyOpt, item.checkCompany) || '-' }}
                  </template>
                </van-field>
                <van-field label="单位类别" input-align="right">
                  <template #input>
                    {{ dictionaryEscape(typeOpt, item.type) || '-' }}
                  </template>
                </van-field>
              </div>
            </div>
          </van-collapse-item>
        </van-collapse>
      </van-form>

      <van-overlay :show="loading">
        <van-loading color="#1989fa" size="24px">详情加载中...</van-loading>
      </van-overlay>
    </div>

  </van-popup>
</template>

<script>
import moment from 'moment'
import { dictionaryEscape } from '@/utils/dictionary'
import programApi from '@/views/Manage/saftyDanger/api/programApi'
import dictContracts from '@/components/dict/DictSelectUtils'
import CmgtSaftyDangerCheckplanApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckplanApi'


export default {
  name: 'DetailsPopup',
  props: {
    // 是否展示弹层
    isShow: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default: () => ({}),
      type: Object
    },
    checkTypeOpt: {
      default: () => ([]),
      type: Array
    },
    typeOpt: {
      default: () => ([]),
      type: Array
    },
    checkCompanyOpt: {
      default: () => ([]),
      type: Array
    }
  },
  data() {
    return {
      formData: {},
      loading: false,
      activeNames: [] // 手风琴展开数组
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.isShow
      },
      set(val) {
        this.$emit('update:isShow', val)
      }
    },
    previewUrl() {
      return window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
    }
  },
  methods: {
    dictionaryEscape,
    moment,

    // 弹层打开
    open() {
      if (this.rowInfo.id) {
        this.loading = true
        CmgtSaftyDangerCheckplanApi.getItemById(this.rowInfo.id, res => {
          const { ...formData } = res
          this.formData = {
            ...formData
          }
          this.activeNames = ['1']
          this.loading = false
        })
      }
    },

    // 弹层关闭
    closed() {
      // 重置组件内的数据
      Object.assign(this.$data, this.$options.data.call(this))
    }
  }
}
</script>

<style lang="scss" scoped>
.details-container {
  width: 100%;
  height: 100%;
  background: #fff;
  display: flex;
  flex-direction: column;

  ::v-deep .van-form {
    flex: 1;
    overflow: auto;
    padding-bottom: 40PX;

    .van-uploader__wrapper {
      .van-uploader__upload {
        display: none;
      }

      .van-uploader__preview-delete {
        display: none;
      }
    }
  }


  ::v-deep .van-action-sheet__close {
    display: none;
  }

  ::v-deep .van-collapse-item__content {
    padding: 0 0 0 20PX;
    margin-bottom: 5PX;

    .multiple-box {
      display: flex;
      flex-direction: column;
      row-gap: 10PX;

      .multiple-box-item {
        border: 1px solid #c9c9c9;
        margin-right: 10PX;
      }
    }


  }

  ::v-deep .van-overlay {
    display: flex;
    justify-content: center;
    align-items: center;
  }

}
</style>
